@@ -26,9 +26,10 @@ from __future__ import annotations
 import asyncio
 import enum
 import dataclasses as dtc
+import inspect
 import logging
 import typing as tp
-from collections.abc import Awaitable, AsyncIterator
+from collections.abc import Awaitable, AsyncIterator, AsyncGenerator
 from contextlib import asynccontextmanager
 from urllib.parse import urlparse
 
@@ -36,7 +37,7 @@ from ..amqp import Message
 from ..cm import ConnectionManager
 from ..types import AMQPBody
 from ._client import PublisherConstr, Publisher, Subscriber
-from .error import ProtocolError
+from .error import ProtocolError, RbFlyError
 from .offset import Offset, OffsetType
 from .protocol import RabbitMQStreamsProtocol
 from .util import retry, suppress
@@ -44,6 +45,7 @@ from .util import retry, suppress
 logger = logging.getLogger(__name__)
 
 T = tp.TypeVar('T')
+S = tp.TypeVar('S')
 P = tp.ParamSpec('P')
 
 class Scheme(enum.Enum):
@@ -406,9 +408,21 @@ def streams_client(uri: str) -> StreamsClient:
     conn_info = ConnectionInfo(scheme, host, port, vhost, p.username, p.password)
     return StreamsClient(conn_info)
 
+@tp.overload
 def connection(
         f: tp.Callable[P, Awaitable[T]]
     ) -> tp.Callable[P, Awaitable[T]]:
+    ...
+
+@tp.overload
+def connection(
+        f: tp.Callable[P, AsyncGenerator[T, S]]
+    ) -> tp.Callable[P, AsyncGenerator[T, S]]:
+    ...
+
+def connection(
+        f: tp.Callable[P, Awaitable[T]] | tp.Callable[P, AsyncGenerator[T, S]]
+    ) -> tp.Callable[P, Awaitable[T]] | tp.Callable[P, AsyncGenerator[T, S]]:
     """
     Decorator to manage RabbitMQ Streams client connection.
 
@@ -419,15 +433,35 @@ def connection(
 
     :param f: Coroutine using RabbitMQ Streams client.
     """
+    f_coro = tp.cast(tp.Callable[P, Awaitable[T]], f)
+    f_gen = tp.cast(tp.Callable[P, AsyncGenerator[T, S]], f)
     async def wrapper(*args: P.args, **kw: P.kwargs) -> T:
         try:
             client = tp.cast(
                 ConnectionManager[RabbitMQStreamsProtocol], args[0]  # type: ignore
             )
-            result = await f(*args, **kw)
+            result = await f_coro(*args, **kw)
         finally:
             await client.disconnect()
         return result
-    return wrapper
+
+    async def wrapper_gen(*args: P.args, **kw: P.kwargs) -> AsyncGenerator[T, S]:
+        try:
+            client = tp.cast(
+                ConnectionManager[RabbitMQStreamsProtocol], args[0]  # type: ignore
+            )
+            async for v in f_gen(*args, **kw):
+                yield v
+        finally:
+            await client.disconnect()
+
+    if inspect.iscoroutinefunction(f):
+        return wrapper
+    elif inspect.isasyncgenfunction(f):
+        return wrapper_gen
+    else:
+        raise RbFlyError(
+            'Asynchronous coroutine or generator function required'
+        )
 
 # vim: sw=4:et:ai
