@@ -340,7 +340,6 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         await task
         return queue
 
-
     async def unsubscribe(self, subscription_id: int) -> tp.Any:
         """
         Unsubscribe from RabbitMQ stream using the subscription id.
@@ -488,7 +487,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
     def connection_made(self, transport: asyncio.BaseTransport) -> None:
         self.transport = Option(tp.cast(asyncio.Transport, transport))
 
-    def connection_lost(self, ex: tp.Optional[Exception]) -> None:
+    def connection_lost(self, ex: Exception | None) -> None:
         self.transport = Option[asyncio.Transport]()
 
         all_tasks = tp.cast(
