@@ -22,8 +22,12 @@ Basic types.
 """
 
 import typing as tp
+from collections.abc import Sequence
 
 AMQPScalar: tp.TypeAlias = str | bool | int | float
-AMQPBody: tp.TypeAlias = bytes | dict[AMQPScalar, AMQPScalar] | AMQPScalar
+AMQPBody: tp.TypeAlias = bytes \
+    | dict[AMQPScalar, AMQPScalar] \
+    | Sequence[AMQPScalar] \
+    | AMQPScalar
 
 # vim: sw=4:et:ai
